# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`avahi`](#avahi): Installs and configures Avahi.
* [`avahi::config`](#avahiconfig)
* [`avahi::daemon`](#avahidaemon)
* [`avahi::install`](#avahiinstall)
* [`avahi::params`](#avahiparams)

### Defined types

* [`avahi::service`](#avahiservice): Statically define a service in Avahi.

### Resource types

* [`avahi_host`](#avahi_host): Manages an Avahi host entry.

### Data types

* [`Avahi::Domain`](#avahidomain)
* [`Avahi::Record`](#avahirecord)

## Classes

### <a name="avahi"></a>`avahi`

Installs and configures Avahi.

* **See also**
  * puppet_defined_types::avahi::service
    * avahi::service

#### Examples

##### Declaring the class

```puppet
include dbus
include avahi
```

#### Parameters

The following parameters are available in the `avahi` class:

* [`conf_dir`](#conf_dir)
* [`dtd_dir`](#dtd_dir)
* [`group`](#group)
* [`package_name`](#package_name)
* [`policy_group`](#policy_group)
* [`service_name`](#service_name)
* [`user`](#user)
* [`validate`](#validate)
* [`xmllint`](#xmllint)
* [`add_service_cookie`](#add_service_cookie)
* [`allow_interfaces`](#allow_interfaces)
* [`allow_point_to_point`](#allow_point_to_point)
* [`browse_domains`](#browse_domains)
* [`cache_entries_max`](#cache_entries_max)
* [`check_response_ttl`](#check_response_ttl)
* [`clients_max`](#clients_max)
* [`deny_interfaces`](#deny_interfaces)
* [`disable_publishing`](#disable_publishing)
* [`disable_user_service_publishing`](#disable_user_service_publishing)
* [`disallow_other_stacks`](#disallow_other_stacks)
* [`domain_name`](#domain_name)
* [`enable_dbus`](#enable_dbus)
* [`enable_reflector`](#enable_reflector)
* [`enable_wide_area`](#enable_wide_area)
* [`entries_per_entry_group_max`](#entries_per_entry_group_max)
* [`host_name`](#host_name)
* [`objects_per_client_max`](#objects_per_client_max)
* [`publish_aaaa_on_ipv4`](#publish_aaaa_on_ipv4)
* [`publish_a_on_ipv6`](#publish_a_on_ipv6)
* [`publish_addresses`](#publish_addresses)
* [`publish_dns_servers`](#publish_dns_servers)
* [`publish_domain`](#publish_domain)
* [`publish_hinfo`](#publish_hinfo)
* [`publish_resolv_conf_dns_servers`](#publish_resolv_conf_dns_servers)
* [`publish_workstation`](#publish_workstation)
* [`ratelimit_burst`](#ratelimit_burst)
* [`ratelimit_interval_usec`](#ratelimit_interval_usec)
* [`reflect_ipv`](#reflect_ipv)
* [`rlimit_as`](#rlimit_as)
* [`rlimit_core`](#rlimit_core)
* [`rlimit_data`](#rlimit_data)
* [`rlimit_fsize`](#rlimit_fsize)
* [`rlimit_nofile`](#rlimit_nofile)
* [`rlimit_nproc`](#rlimit_nproc)
* [`rlimit_stack`](#rlimit_stack)
* [`use_iff_running`](#use_iff_running)
* [`use_ipv4`](#use_ipv4)
* [`use_ipv6`](#use_ipv6)

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`

The top-level configuration directory, usually `/etc/avahi`.

Default value: `$avahi::params::conf_dir`

##### <a name="dtd_dir"></a>`dtd_dir`

Data type: `Stdlib::Absolutepath`

The directory containing the XML DTD for service validation.

Default value: `$avahi::params::dtd_dir`

##### <a name="group"></a>`group`

Data type: `String`

The unprivileged group used to run the daemon.

Default value: `$avahi::params::group`

##### <a name="package_name"></a>`package_name`

Data type: `String`

The name of the package.

Default value: `$avahi::params::package_name`

##### <a name="policy_group"></a>`policy_group`

Data type: `String`

The group that is allowed by policy to set the mDNS
hostname.

Default value: `$avahi::params::policy_group`

##### <a name="service_name"></a>`service_name`

Data type: `String`

The service name.

Default value: `$avahi::params::service_name`

##### <a name="user"></a>`user`

Data type: `String`

The unprivileged user used to run the daemon.

Default value: `$avahi::params::user`

##### <a name="validate"></a>`validate`

Data type: `Boolean`

Whether to try and validate service files prior to installing
them.

Default value: `$avahi::params::validate`

##### <a name="xmllint"></a>`xmllint`

Data type: `Stdlib::Absolutepath`

The path to the xmllint binary used to validate service files.

Default value: `$avahi::params::xmllint`

##### <a name="add_service_cookie"></a>`add_service_cookie`

Data type: `Optional[Boolean]`

Whether a unique cookie is added to all locally
registered services.

Default value: ``undef``

##### <a name="allow_interfaces"></a>`allow_interfaces`

Data type: `Optional[Array[String, 1]]`

Interfaces to allow mDNS traffic on.

Default value: ``undef``

##### <a name="allow_point_to_point"></a>`allow_point_to_point`

Data type: `Optional[Boolean]`

Include Point-to-Point interfaces.

Default value: ``undef``

##### <a name="browse_domains"></a>`browse_domains`

Data type: `Optional[Array[Bodgitlib::Domain, 1]]`

Additional browse domains.

Default value: `$avahi::params::browse_domains`

##### <a name="cache_entries_max"></a>`cache_entries_max`

Data type: `Optional[Integer[0]]`

How many entries are cached per interface.

Default value: ``undef``

##### <a name="check_response_ttl"></a>`check_response_ttl`

Data type: `Optional[Boolean]`

Whether to check the TTL of mDNS packets.

Default value: ``undef``

##### <a name="clients_max"></a>`clients_max`

Data type: `Optional[Integer[0]]`

Maximum number of D-Bus clients permitted.

Default value: ``undef``

##### <a name="deny_interfaces"></a>`deny_interfaces`

Data type: `Optional[Array[String, 1]]`

Interfaces to explicitly deny mDNS traffic on.

Default value: ``undef``

##### <a name="disable_publishing"></a>`disable_publishing`

Data type: `Optional[Boolean]`

Disable publishing of any records.

Default value: ``undef``

##### <a name="disable_user_service_publishing"></a>`disable_user_service_publishing`

Data type: `Optional[Boolean]`

Disable publishing of records by user
applications.

Default value: ``undef``

##### <a name="disallow_other_stacks"></a>`disallow_other_stacks`

Data type: `Optional[Boolean]`

Whether to allow other mDNS stacks to run on the
host.

Default value: ``undef``

##### <a name="domain_name"></a>`domain_name`

Data type: `Optional[String]`

Override the domain name used, `.local` normally.

Default value: ``undef``

##### <a name="enable_dbus"></a>`enable_dbus`

Data type: `Optional[Boolean]`

Whether to connect to D-Bus.

Default value: ``undef``

##### <a name="enable_reflector"></a>`enable_reflector`

Data type: `Optional[Boolean]`

Whether to enable the mDNS reflector.

Default value: ``undef``

##### <a name="enable_wide_area"></a>`enable_wide_area`

Data type: `Optional[Boolean]`

Enable wide-area mDNS.

Default value: `$avahi::params::enable_wide_area`

##### <a name="entries_per_entry_group_max"></a>`entries_per_entry_group_max`

Data type: `Optional[Integer[0]]`

The maximum number of entries to be
registered by a single D-Bus client.

Default value: ``undef``

##### <a name="host_name"></a>`host_name`

Data type: `Optional[String]`

Override the hostname used for the local machine.

Default value: ``undef``

##### <a name="objects_per_client_max"></a>`objects_per_client_max`

Data type: `Optional[Integer[0]]`

The maximum number of objects to be registered
by a single D-Bus client.

Default value: ``undef``

##### <a name="publish_aaaa_on_ipv4"></a>`publish_aaaa_on_ipv4`

Data type: `Optional[Boolean]`

Whether to publish AAAA records via IPv4.

Default value: ``undef``

##### <a name="publish_a_on_ipv6"></a>`publish_a_on_ipv6`

Data type: `Optional[Boolean]`

Whether to publish A records via IPv6.

Default value: ``undef``

##### <a name="publish_addresses"></a>`publish_addresses`

Data type: `Optional[Boolean]`

Whether to publish mDNS address records for all
local IP addresses.

Default value: ``undef``

##### <a name="publish_dns_servers"></a>`publish_dns_servers`

Data type: `Optional[Array[Stdlib::IP::Address::NoSubnet, 1]]`

List of unicast DNS servers to publish in mDNS.

Default value: ``undef``

##### <a name="publish_domain"></a>`publish_domain`

Data type: `Optional[Boolean]`

Whether to announce the local domain name for browsing
by other hosts.

Default value: ``undef``

##### <a name="publish_hinfo"></a>`publish_hinfo`

Data type: `Optional[Boolean]`

Whether to publish `HINFO` records on all interfaces.

Default value: `$avahi::params::publish_hinfo`

##### <a name="publish_resolv_conf_dns_servers"></a>`publish_resolv_conf_dns_servers`

Data type: `Optional[Boolean]`

Whether to publish the DNS servers
listed in `/etc/resolv.conf` in addition to any listed in
`publish_dns_servers`.

Default value: ``undef``

##### <a name="publish_workstation"></a>`publish_workstation`

Data type: `Optional[Boolean]`

Whether to publish a workstation record for the
local machine.

Default value: `$avahi::params::publish_workstation`

##### <a name="ratelimit_burst"></a>`ratelimit_burst`

Data type: `Optional[Integer[0]]`

Per-interface packet rate-limiting burst parameter.

Default value: `$avahi::params::ratelimit_burst`

##### <a name="ratelimit_interval_usec"></a>`ratelimit_interval_usec`

Data type: `Optional[Integer[0]]`

Per-interface packet rate-limiting interval
parameter.

Default value: `$avahi::params::ratelimit_interval_usec`

##### <a name="reflect_ipv"></a>`reflect_ipv`

Data type: `Optional[Boolean]`

Whether to reflect between IPv4 and IPv6.

Default value: ``undef``

##### <a name="rlimit_as"></a>`rlimit_as`

Data type: `Optional[Integer[0]]`

Value in bytes for `RLIMIT_AS`.

Default value: ``undef``

##### <a name="rlimit_core"></a>`rlimit_core`

Data type: `Optional[Integer[0]]`

Value in bytes for `RLIMIT_CORE`.

Default value: `$avahi::params::rlimit_core`

##### <a name="rlimit_data"></a>`rlimit_data`

Data type: `Optional[Integer[0]]`

Value in bytes for `RLIMIT_DATA`.

Default value: `$avahi::params::rlimit_data`

##### <a name="rlimit_fsize"></a>`rlimit_fsize`

Data type: `Optional[Integer[0]]`

Value for `RLIMIT_FSIZE`.

Default value: `$avahi::params::rlimit_fsize`

##### <a name="rlimit_nofile"></a>`rlimit_nofile`

Data type: `Optional[Integer[0]]`

Value for `RLIMIT_NOFILE`.

Default value: `$avahi::params::rlimit_nofile`

##### <a name="rlimit_nproc"></a>`rlimit_nproc`

Data type: `Optional[Integer[2]]`



Default value: `$avahi::params::rlimit_nproc`

##### <a name="rlimit_stack"></a>`rlimit_stack`

Data type: `Optional[Integer[0]]`



Default value: `$avahi::params::rlimit_stack`

##### <a name="use_iff_running"></a>`use_iff_running`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="use_ipv4"></a>`use_ipv4`

Data type: `Optional[Boolean]`



Default value: `$avahi::params::use_ipv4`

##### <a name="use_ipv6"></a>`use_ipv6`

Data type: `Optional[Boolean]`



Default value: `$avahi::params::use_ipv6`

### <a name="avahiconfig"></a>`avahi::config`

The avahi::config class.

### <a name="avahidaemon"></a>`avahi::daemon`

The avahi::daemon class.

### <a name="avahiinstall"></a>`avahi::install`

The avahi::install class.

### <a name="avahiparams"></a>`avahi::params`

The avahi::params class.

## Defined types

### <a name="avahiservice"></a>`avahi::service`

Statically define a service in Avahi.

* **See also**
  * puppet_classes::avahi
    * avahi
  * https://linux.die.net/man/5/avahi.service
    * avahi.service(5)

#### Examples

##### Add static service definitions for SSH and SFTP

```puppet
include dbus
include avahi

avahi::service { 'ssh':
  description       => '%h',
  replace_wildcards => true,
  services          => [
    {
      'type' => '_ssh._tcp',
      'port' => 22,
    },
  ],
}

avahi::service { 'sftp-ssh':
  description       => '%h',
  replace_wildcards => true,
  services          => [
    {
      'type' => '_sftp-ssh._tcp',
      'port' => 22,
    },
  ],
}
```

##### Add a static service definition for NFS on IPv6 only

```puppet
include dbus
include avahi

avahi::service { 'nfs':
  description       => 'NFS on %h',
  replace_wildcards => true,
  services          => [
    {
      'type'       => '_nfs._tcp',
      'port'       => 2049,
      'protocol'   => 'ipv6',
      'txt-record' => [
        'path=/export/some/path',
      ],
    },
  ],
}
```

##### Advertise an AirPrint printer

```puppet
include dbus
include avahi

avahi::service { 'printer':
  description => 'An AirPrint printer',
  services    => [
    {
      'type'       => '_ipp._tcp',
      'subtype'    => [
        '_universal._sub._ipp._tcp',
      ],
      'port'       => 631,
      'txt-record' => [
        'txtver=1',
        'qtotal=1',
        'rp=printers/aPrinter',
        'ty=aPrinter',
        'adminurl=http://198.0.2.1:631/printers/aPrinter',
        'note=Office Laserjet 4100n',
        'priority=0',
        'product=(GPL Ghostscript)',
        'printer-state=3',
        'printer-type=0x801046',
        'Transparent=T',
        'Binary=T',
        'Fax=F',
        'Color=T',
        'Duplex=T',
        'Staple=F',
        'Copies=T',
        'Collate=F',
        'Punch=F',
        'Bind=F',
        'Sort=F',
        'Scan=F',
        'pdl=application/octet-stream,application/pdf,application/postscript,image/jpeg,image/png,image/urf',
        'URF=W8,SRGB24,CP1,RS600',
      ],
    },
  ],
}
```

#### Parameters

The following parameters are available in the `avahi::service` defined type:

* [`description`](#description)
* [`services`](#services)
* [`replace_wildcards`](#replace_wildcards)
* [`service`](#service)

##### <a name="description"></a>`description`

Data type: `String`

The description of the service, any occurence of `%h` will
be replaced with the hostname if `$replace_wildcards` is set to `true`.

##### <a name="services"></a>`services`

Data type: `Array[Avahi::Record, 1]`

An array of hashes which must contain `type` and `port` keys
and optionally `protocol`, `subtype`, `domain-name`, `host-name` and
`txt-record` keys.

##### <a name="replace_wildcards"></a>`replace_wildcards`

Data type: `Optional[Boolean]`

Whether any occurence of `%h` is replaced with the
hosname.

Default value: ``undef``

##### <a name="service"></a>`service`

Data type: `String`

The name of the service. It is used to construct the filename,
i.e. `${conf_dir}/services/${service}.service`.

Default value: `$title`

## Resource types

### <a name="avahi_host"></a>`avahi_host`

Manages an Avahi host entry.

#### Examples

##### Add a static host entry on behalf of an mDNS-unaware router

```puppet
include ::dbus
include ::avahi

avahi_host { 'router.local':
  ensure => present,
  ip     => '192.0.2.1',
}
```

#### Properties

The following properties are available in the `avahi_host` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `ip`

The IP address of the host, either IPv4 or IPv6.

#### Parameters

The following parameters are available in the `avahi_host` type.

* [`name`](#name)
* [`provider`](#provider)
* [`target`](#target)

##### <a name="name"></a>`name`

namevar

The host name.

##### <a name="provider"></a>`provider`

The specific backend to use for this `avahi_host` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="target"></a>`target`

The file in which to store the settings, defaults to `/etc/avahi/hosts`.

Default value: `/etc/avahi/hosts`

## Data types

### <a name="avahidomain"></a>`Avahi::Domain`

The Avahi::Domain data type.

Alias of

```puppet
Pattern[/(?x) ^ ( (?= [a-z0-9._-]{2,255} ) ( (?= [a-z0-9_-]{1,63} \. ) _ [a-z0-9]+ ( - [a-z0-9]+ )* \. )+ _ [a-z]{2,62} ) $/]
```

### <a name="avahirecord"></a>`Avahi::Record`

The Avahi::Record data type.

Alias of

```puppet
Struct[{'type' => Avahi::Domain, 'port' => Integer[0, 65535], Optional['protocol'] => Enum['ipv4', 'ipv6', 'any'], Optional['subtype'] => Array[Avahi::Domain], Optional['domain-name'] => String, Optional['host-name'] => Bodgitlib::Domain, Optional['txt-record'] => Array[String]}]
```

